@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 use vars qw( $VERSION );
-$VERSION = '0.03';
+$VERSION = '0.09';
 
 use Carp qw( croak );
 use Config::Tiny;
@@ -12,7 +12,7 @@ use base qw( Class::Accessor );
 my @variables = qw(
    dbtype dbname dbuser dbpass dbport dbhost dbencoding
    script_name install_directory script_url
-   custom_lib_path use_plucene indexing_directory enable_page_deletion
+   custom_lib_path use_plucene use_lucy indexing_directory enable_page_deletion
    admin_pass stylesheet_url site_name navbar_on_home_page
    recent_changes_on_home_page random_page_omits_locales
    random_page_omits_categories content_above_navbar_in_html home_name
@@ -20,12 +20,14 @@ my @variables = qw(
    default_language http_charset ping_services
    formatting_rules_node formatting_rules_link backlinks_in_title template_path
    custom_template_path geo_handler ellipsoid gmaps_api_key centre_long
-   show_gmap_in_node_display google_analytics_key
+   show_gmap_in_node_display google_analytics_key use_leaflet
    centre_lat default_gmaps_zoom default_gmaps_search_zoom force_wgs84
-   licence_name licence_url licence_info_url moderation_requires_password
+   licence_name licence_url licence_info_url
+   moderation_requires_password moderate_whitelist
    enable_node_image enable_common_categories enable_common_locales
-   spam_detector_module host_checker_module static_path static_url
-   send_moderation_notifications
+   spam_detector_module host_checker_module custom_macro_module
+   static_path static_url
+   send_moderation_notifications website_link_max_chars read_only
 );
 my @questions = map { $_ . "__qu" } @variables;
 OpenGuides::Config->mk_accessors( @variables );
@@ -73,13 +75,15 @@ sub _init {
     # Here are the defaults for the variable values.
     # Don't forget to add to INSTALL when changing these.
     my %defaults = (
-                     dbtype => "postgres",
+                     dbtype => "sqlite",
                      script_name => "wiki.cgi",
                      install_directory => "/usr/lib/cgi-bin/openguides/",
                      use_plucene => 1,
+                     use_lucy => 0,
                      indexing_directory => "/usr/lib/cgi-bin/openguides/indexes/",
                      enable_page_deletion => 0,
                      moderation_requires_password => 1,
+                     moderate_whitelist => "",
                      admin_pass => "Change This!",
                      enable_node_image => 1,
                      enable_common_categories => 0,
@@ -98,10 +102,11 @@ sub _init {
                      default_language => "en",
                      http_charset => "",
                      formatting_rules_node => "Text Formatting Examples",
-                     formatting_rules_link => "http://openguides.org/page/text_formatting",
+                     formatting_rules_link => "http://openguides.org/text_formatting",
                      backlinks_in_title => 0,
                      geo_handler => 1,
                      ellipsoid => "WGS-84",
+                     use_leaflet => 0,
                      show_gmap_in_node_display => 1,
                      centre_long => 0,
                      centre_lat => 0,
@@ -113,8 +118,11 @@ sub _init {
                      licence_info_url => "",
                      spam_detector_module => "",
                      host_checker_module => "",
+                     custom_macro_module => "",
                      static_path => "/usr/local/share/openguides/static",
-                     send_moderation_notifications => 1
+                     send_moderation_notifications => 1,
+                     website_link_max_chars => 25,
+                     read_only => 0,
                    );
 
     # See if we already have some config variables set.
@@ -158,11 +166,12 @@ sub _init {
         script_url => "What URL does the install directory map to?",
         custom_lib_path => "Do you want me to munge a custom lib path into the scripts?  If so, enter it here.  Separate path entries with whitespace.",
         use_plucene => "Do you want to use Plucene for searching? (recommended, but see Changes file before saying yes to this if you are upgrading)",
+        use_lucy => "Do you want to use Lucy for searching? (experimental)",
         indexing_directory => "What directory can I use to store indexes in for searching? ***NOTE*** This directory must exist and be writeable by the user that your script will run as.  See README for more on this.",
         enable_page_deletion => "Do you want to enable page deletion?",
         moderation_requires_password => "Is the admin password required for moderating pages?",
         admin_pass => "Please specify a password for the site admin.",
-        stylesheet_url => "What's the URL of the site's stylesheet?",
+        stylesheet_url => "What's the URL of the site's stylesheet?  If you don't enter one here, the basic OpenGuides stylesheet will be used instead.",
         enable_node_image => "Should nodes be allowed to have an externally hosted image?",
         enable_common_categories => "Do you want a common list of categories shown on all node pages?",
         enable_common_locales => "Do you want a common list of locales shown on all node pages?",
@@ -184,12 +193,13 @@ sub _init {
         formatting_rules_link => "What URL do you want to use for the text formatting rules (leave blank to use a wiki node instead)?",
         backlinks_in_title => "Make node titles link to node backlinks (C2 style)?",
         ellipsoid => "Which ellipsoid do you want to use? (eg 'Airy', 'WGS-84')",
-        gmaps_api_key => "Do you have a Google Maps API key to use with this guide? If you enter it here the Google Maps functionality will be automatically enabled.",
-        centre_long => "What is the longitude of the centre point of a map to draw for your guide? (This question can be ignored if you aren't using Google Maps). You may paste in a Google Maps URL here (hint: copy URL from 'Link to this page')",
-        centre_lat => "What is the latitude of the centre point of a map to draw for your guide? (This question can be ignored if you aren't using Google Maps)",
+        use_leaflet => "Do you want to use the Leaflet mapping library? (this is recommended)",
+        gmaps_api_key => "Do you have a Google Maps API key to use with this guide? If so, enter it here. (Note: our Google Maps support is deprecated, and we recommend you choose to use Leaflet instead.)",
+        centre_long => "What is the longitude of the centre point of a map to draw for your guide? (This question can be ignored if you aren't using Google Maps - we recommend you use Leaflet instead, as our Leaflet code will figure this out for you.) You may paste in a Google Maps URL here (hint: copy URL from 'Link to this page')",
+        centre_lat => "What is the latitude of the centre point of a map to draw for your guide? (This question can be ignored if you aren't using Google Maps - we recommend you use Leaflet instead, as our Leaflet code will figure this out for you.)",
         default_gmaps_zoom => "What default zoom level shall we use for Google Maps? (This question can be ignored if you aren't using Google Maps)",
         default_gmaps_search_zoom => "What default zoom level shall we use for Google Maps in the search results? (This question can be ignored if you aren't using Google Maps)",
-        show_gmap_in_node_display => "Would you like to display a Google Map on every node that has geodata? (This question can be ignored if you aren't using Google Maps)",
+        show_gmap_in_node_display => "Would you like to display a map on every node that has geodata?",
         force_wgs84 => "Forcibly treat stored lat/long data as if they used the WGS84 ellipsoid?",
         google_analytics_key => "Do you have a Google Analytics key to use with this guide? If you enter it here, then Google Analytics functionality will be automatically enabled.",
         licence_name => "What licence will you use for the guide?",
@@ -197,9 +207,13 @@ sub _init {
         licence_info_url => "What is the URL to your local page about your licensing policy?",
         spam_detector_module => "What module would you like to use for spam detection? (optional)",
         host_checker_module => "What module would you like to use to run an IP blacklist? (optional)",
+        custom_macro_module => "What module would you like to use to define custom macros? (optional)",
         static_path => "What directory should we install static content (CSS, images, javascript) to?",
         static_url => "What is the URL corresponding to the static content?",
-        send_moderation_notifications => "Should we send email notifications when a moderated node is edited?"
+        send_moderation_notifications => "Should we send email notifications when a moderated node is edited?",
+        website_link_max_chars => "How many characters of the URL of node websites should be displayed?",
+        moderate_whitelist => "Enter a comma-separated list of IP addresses able to make changes to moderated nodes and have them show up immediately",
+        read_only => "Should the guide be read-only (no edits permitted)?",
     );
 
     foreach my $var ( keys %questions ) {
@@ -258,6 +272,8 @@ sub script_url {
 
 =item * use_plucene (default: true)
 
+=item * use_lucy (default: false)
+
 =item * indexing_directory (default: C</usr/lib/cgi-bin/openguides/indexes>)
 
 =item * enable_page_deletion (default: false)
@@ -294,7 +310,7 @@ sub script_url {
 
 =item * formatting_rules_node (default: C<Text Formatting Examples>)
 
-=item * formatting_rules_link (default: C<http://openguides.org/page/text_formatting>
+=item * formatting_rules_link (default: C<http://openguides.org/text_formatting>
 
 =item * backlinks_in_title (default: false)
 
@@ -302,6 +318,8 @@ sub script_url {
 
 =item * ellipsoid (default: C<WGS-84>)
 
+=item * use_leaflet
+
 =item * gmaps_api_key
 
 =item * centre_long
@@ -328,12 +346,30 @@ sub script_url {
 
 =item * host_checker_module
 
+=item * custom_macro_module
+
 =item * static_path
 
-=item * static_url
+=item * static_url (this is constrained to always end in C</>)
+
+=cut
+
+sub static_url {
+    my $self = shift;
+    # See perldoc Class::Accessor - can't just use SUPER.
+    my $url = $self->_static_url_accessor( @_ );
+    $url .= "/" unless (defined $url && $url =~ /\/$/);
+    return $url;
+}
 
 =item * send_moderation_notifications
 
+=item * moderate_whitelist
+
+=item * website_link_max_chars (default: C<25>)
+
+=item * read_only
+
 =back
 
 =head1 AUTHOR
@@ -342,7 +378,7 @@ The OpenGuides Project (openguides-dev@lists.openguides.org)
 
 =head1 COPYRIGHT
 
-     Copyright (C) 2004-2008 The OpenGuides Project.  All Rights Reserved.
+     Copyright (C) 2004-2013 The OpenGuides Project.  All Rights Reserved.
 
 The OpenGuides distribution is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
